/* bscat_scaling.c -- Factor accounting for non-isotropic phase
   function near 180 deg

   Copyright (C) 2004-2005 Robin Hogan <r.j.hogan@reading.ac.uk> 

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <math.h>

#include "multiscatter.h"

ms_real
bscat_scaling(ms_real bscat_peak_factor, ms_real bscat_peak_width,
	      ms_real width2)
{
  
  if (bscat_peak_width > 0.0) {
    /* Positive width is interpretted as a Gaussian phase function
       near 180 deg */
    return (1.0-bscat_peak_factor+bscat_peak_factor
	    *bscat_peak_width*bscat_peak_width
	    /(width2+bscat_peak_width*bscat_peak_width));
  }
  else if (bscat_peak_width < 0.0) {
    /* Negative width is interpretted as an inverse-exponential phase
       function near 180 deg, appropriate for Ping Yang's ice
       particles */
    /* We ought to use the full expression with an error function, but
       it has a problem with round-off error, so this is simpler */
    ms_real equiv_bscat_peak_width2 = 0.5*pow(-bscat_peak_width, 3.6);
    return pow(1.0-bscat_peak_factor+bscat_peak_factor
	       *equiv_bscat_peak_width2/(width2+equiv_bscat_peak_width2),
	       1.6);
  }
  /* A zero bscat_peak_width shouldn't really be given */
  else if (width2 > 0.0) {
    return bscat_peak_factor;
  }
  else {
    return 1.0;
  }
}
